@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class PhoneAuthConfig(AppConfig):
-    name = 'phone_auth'
+    name = "phone_auth"
